@@ -26,6 +26,7 @@ use PPM::XML::PPD;
 use PPM::XML::PPMConfig;
 use XML::Parser;
 use Archive::Tar;
+use Archive::Zip;
 
 use strict;
 
@@ -113,8 +114,10 @@ chmod(0600, $PPM::PPMdat);
 
 # add -5.d to archname for Perl >= 5.8 
 my $varchname = $Config{archname};
-if (length($^V) && ord(substr($^V,1)) >= 8) {
-    $varchname .= sprintf("-%d.%d", ord($^V), ord(substr($^V,1)));
+if ($] >= 5.008) {
+    my $vstring = sprintf "%vd", $^V;
+    $vstring =~ s/\.\d+$//;
+    $varchname .= "-$vstring";
 }
 
 #
@@ -351,15 +354,26 @@ sub InstallPackage
     $cwd .= "/" if $cwd =~ /[a-z]:$/i;
     chdir($install_dir);
 
-    my $tar;
-    if ($basename =~ /\.gz$/i) {
-        $tar = Archive::Tar->new($basename,1);
+    my ($tarzip, $have_zip);
+    if ($basename =~ /\.zip$/i) {
+        $have_zip = 1;
+        $tarzip = Archive::Zip->new($basename);
+        $tarzip->extractTree();
+    }
+    elsif ($basename =~ /\.gz$/i) {
+        $tarzip = Archive::Tar->new($basename,1);
     }
     else {
-        $tar = Archive::Tar->new($basename,0);
+        $tarzip = Archive::Tar->new($basename,0);
+    }
+
+    if ($have_zip) {
+        $basename =~ /(.*).zip/i;
+    }
+    else {
+        $tarzip->extract($tarzip->list_files);
+        $basename =~ /(.*).tar/i;
     }
-    $tar->extract($tar->list_files);
-    $basename =~ /(.*).tar/i;
     chdir($1);
     RelocPerl('.') if ($Config{'osname'} ne 'MSWin32');
 
